

.. index:: class; multiple


Multiple Classes Practice
=============================

#.

   .. selectquestion:: mult_class_point_and_line_practice_sq
      :fromid: mult_class_point_and_line_practice_ac, mult_class_point_and_line_practice_pp
      :toggle: lock

#.
   .. selectquestion:: mult_class_point_and_triangle_practice_sq
      :fromid: mult_class_point_and_triangle_practice_pp, mult_class_point_and_triangle_practice_ac
      :toggle:

#.
   .. selectquestion:: mult_class_track_and_album_len_sq
      :fromid: mult_class_track_and_album_len_ac, mult_class_track_and_album_len_pp
      :toggle: lock

#.
   .. selectquestion:: mult_class_item_order_line_order_practice_sq
      :fromid: mult_class_item_order_line_order_practice_pp, mult_class_item_order_line_order_practice_ac
      :toggle:

#.
   .. selectquestion:: mult_class_card_and_deck_practice_sq
      :fromid: mult_class_card_and_deck_practice_ac, mult_class_card_and_deck_practice_pp
      :toggle: lock
